@@ -9,13 +9,14 @@
 #ifndef NEXTCLOUD_H
 #define NEXTCLOUD_H
 
-#include <QUrl>
 #include <QHash>
+#include <QUrl>
 
 #include <kaccountsuiplugin.h>
 
-namespace KDeclarative {
-    class QmlObject;
+namespace KDeclarative
+{
+class QmlObject;
 }
 
 class NextcloudWizard : public KAccountsUiPlugin
@@ -25,7 +26,7 @@ class NextcloudWizard : public KAccountsUiPlugin
     Q_INTERFACES(KAccountsUiPlugin)
 
 public:
-    explicit NextcloudWizard(QObject *parent = 0);
+    explicit NextcloudWizard(QObject *parent = nullptr);
     virtual ~NextcloudWizard();
 
     virtual void init(KAccountsUiPlugin::UiType type) override;
@@ -39,4 +40,4 @@ private:
     KDeclarative::QmlObject *m_object;
 };
 
-#endif //NEXTCLOUD_H
+#endif // NEXTCLOUD_H
